@@ -76,7 +76,7 @@ def imports(enums_module: str) -> str:
         "from decimal import Decimal",
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
         "from pydantic import BaseModel, Field, PrivateAttr, validator",
-        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str",
+        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str, BasePatch",
         f"from .{enums_module} import *",
         'EdgeResolverType = T.TypeVar("EdgeResolverType", bound=Resolver)',
     ]
@@ -493,7 +493,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     # patch type
     patch_inner_str = "\n".join(patch_property_strs)
     patch_conversion_map_str = f"_edgedb_conversion_map: T.ClassVar[T.Dict[str, str]] = {stringify_dict(patch_edgedb_conversion_map)}"
-    patch_s = f"class {patch_model_name}(BaseModel):\n{indent_lines(patch_inner_str)}\n\n{indent_lines(patch_conversion_map_str)}"
+    patch_s = f"class {patch_model_name}(BasePatch):\n{indent_lines(patch_inner_str)}\n\n{indent_lines(patch_conversion_map_str)}"
 
     # node
     node_properties_str = "\n".join(property_strs)
