@@ -444,8 +444,9 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         print(f"{full_insert_str=}")
         data: T.List[T.Dict[str, T.Any]] = []
         for insert in inserts:
-            # d = insert.dict(exclude_none=True)
-            d = insert.dict()
+            d = insert.dict(exclude_none=True)
+            # TODO for bulk adding, best to exclude
+            # d = insert.dict()
             # if the cast says they should be strings and they are not, turn them into json
             for field_name, value in d.items():
                 if cast := cls._edgedb_conversion_map.get(field_name, {}).get("cast"):
